"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addFingerJoints = void 0;
const core_1 = require("./core");
const finger_joints_1 = require("finger-joints");
const line_utils_1 = require("line-utils");
const index_1 = require("./index");
function addFingerJoints(from, to, options) {
    const fingerJointGenerator = new finger_joints_1.FingerJointGenerator({
        fingerLength: options.fingerSize,
        spaceLength: options.spaceSize,
        startWith: options.startWithFinger ? "FINGER" : "SPACE",
        endWith: options.isInside ? "FINGER" : "SPACE",
        rounding: "GROW_BOTH",
    });
    const line = new line_utils_1.Line(from, to);
    const fingerStack = fingerJointGenerator.generate(line.length);
    const group = new core_1.Group({ insert: false });
    fingerStack.data
        .filter((finger) => finger.type === "FINGER")
        .map((finger) => {
        new core_1.Path.Rectangle({
            center: line.lerp(finger.centerTime),
            size: (0, index_1.size)(finger.length, options.isInside ? options.woodThickness : options.woodThickness * 2),
            strokeColor: "black",
        }).addTo(group);
    });
    return group;
}
exports.addFingerJoints = addFingerJoints;
//# sourceMappingURL=finger-joints.js.map