import { PathType } from "./index";

interface BooleanOptions {
  insert: boolean;
}

interface BooleanOptionsWithTrace extends BooleanOptions {
  trace: boolean;
}

interface CustomBooleanOptions {
  removeOld: boolean;
}

export function unite(
  paths: PathType[],
  options: Partial<BooleanOptions & CustomBooleanOptions> = {}
): PathType {
  return paths.reduce((path1, path2) => {
    const newPath = path1.unite(path2, options);

    if (options.removeOld) {
      path1.remove();
      path2.remove();
    }
    return newPath as PathType;
  });
}

export function intersect(
  paths: PathType[],
  options: Partial<BooleanOptionsWithTrace & CustomBooleanOptions> = {}
): PathType {
  return paths.reduce((path1, path2) => {
    const newPath = path1.intersect(path2, options);
    if (options.removeOld) {
      path1.remove();
      path2.remove();
    }
    return newPath as PathType;
  });
}

export function subtract(
  paths: PathType[],
  options: Partial<BooleanOptionsWithTrace & CustomBooleanOptions> = {}
): PathType {
  return paths.reduce((path1, path2) => {
    const newPath = path1.subtract(path2, options);
    if (options.removeOld) {
      path1.remove();
      path2.remove();
    }
    return newPath as PathType;
  });
}
