import { Group, Path } from "./core";
import { FingerJointGenerator } from "finger-joints";
import { Line, PointDef } from "line-utils";
import { size } from "./index";

export function addFingerJoints(
  from: PointDef,
  to: PointDef,
  options: {
    fingerSize: number;
    spaceSize: number;
    woodThickness: number;
    isInside: boolean;
    startWithFinger: boolean;
  }
): Group {
  const fingerJointGenerator = new FingerJointGenerator({
    fingerLength: options.fingerSize,
    spaceLength: options.spaceSize,
    startWith: options.startWithFinger ? "FINGER" : "SPACE",
    endWith: options.isInside ? "FINGER" : "SPACE",
    rounding: "GROW_BOTH",
  });

  const line = new Line(from, to);
  const fingerStack = fingerJointGenerator.generate(line.length);
  const group = new Group({ insert: false });
  fingerStack.data
    .filter((finger) => finger.type === "FINGER")
    .map((finger) => {
      new Path.Rectangle({
        center: line.lerp(finger.centerTime),
        size: size(
          finger.length,
          options.isInside ? options.woodThickness : options.woodThickness * 2
        ),
        strokeColor: "black",
      }).addTo(group);
    });
  return group;
}
